@@ -163,6 +163,9 @@ class SMTContext
         $session = $this->getSessionContext( FALSE );
         $session->setUser( NULL );
         $session->closeSession();
+        
+        //cleanup options at logout
+        SMTSmartOtuSettings::setOtuOption(NULL);
     }
     
     /**
