@@ -399,6 +399,11 @@ class SMTLinkTestDto extends SMTRwDto implements SMTIMemorySupport
     	return $this->peakOpticalAlarm;
     }  
     
+    public function stripHtmlTags()
+    {
+    	$this->name= strip_tags( $this->name);
+    }
+    
     /**
      * Serialize as Json data (array) the object.<br> 
      * 
@@ -430,7 +435,10 @@ class SMTLinkTestDto extends SMTRwDto implements SMTIMemorySupport
      */
     static function getInstance( array &$json_array )
     {
-    	return self::forge( get_class(), $json_array );
+    	
+    	$instance = self::forge( get_class(), $json_array );
+    	$instance->stripHtmlTags();
+    	return $instance;
     }    
     
     /**
