@@ -209,14 +209,16 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
      * Retrieve OTDR acquisition for the given trace name and the given trace type
      *
      * @url GET /downloadtracefile
+     * @param $attachmentFileName
+     * @param $traceStorageType
      * @status 200
      * @access protected
      * @class SMTAccessControl {@requires user}
      */
-    function downloadOtdrTraceFile( $request_data  )
+    function downloadOtdrTraceFile( $attachmentFileName, $traceStorageType )
     {
-        $traceName = $request_data['attachmentFileName'];
-        $otdrTraceType = $request_data['traceStorageType'];
+    	$traceName = $attachmentFileName;
+    	$otdrTraceType = $traceStorageType;
         $newFilePath = '';
         
         try
@@ -240,7 +242,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
             
             SMTLogger::getInstance()->trace( sprintf("Retrieve otdr trace file %s ",  $newFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
             
-            if ( strlen( $newFilePath ) > 0 )
+            if ( file_exists($newFilePath) )
             {
             	$page = new SMTOtdrTraceFileDownloadPage( $newFilePath, $otdrTraceType );
     	        $this->getContext()->getHttpResponse()->send( $page );
@@ -269,6 +271,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     {
     	$SOM = 0;
     	$EOM = 0;
+    	$newFilePath = NULL;
         try 
         {
             if ( SMTOperationManager::hasOperation( $operationId ) )
@@ -298,8 +301,11 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
             }
             
         	//backup OTDR file to the smartOTU directory to be used for monitoring test addition
-        	$newFilePath = SMTSessionDirectoryUtil::backupOTDRTraceToSessionDirectory( $traceFilePath, $portNumber, $operationId );
-        	SMTLogger::getInstance()->trace( sprintf("Acquisition backup trace in SmartOtu %s ",  $newFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);        	
+            if ( file_exists( $traceFilePath ) )
+            {
+        		$newFilePath = SMTSessionDirectoryUtil::backupOTDRTraceToSessionDirectory( $traceFilePath, $portNumber, $operationId );
+        		SMTLogger::getInstance()->trace( sprintf("Acquisition backup trace in SmartOtu %s ",  $newFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+            }
         	        	
         	$smartAcqTraceExtension = SMTBaseOtdrTraceFileUtil::getSmartAcqFileExtension($traceFilePath);
         	// if smart acq
