@@ -108,6 +108,29 @@ class SMTEthernetService extends SMTService implements SMTIService
         return $hostName;        
     }
     
+    /**
+     *
+     * @url GET /name
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function getName()
+    {
+    	$name = '';
+    	
+    	try
+    	{
+    		$name= $this->sendReceive( SMTOtuApi::CMD_get_otu_name);
+    	}
+    	catch ( \Exception $e )
+    	{
+    		$this->handleException($e);
+    	}
+    	
+    	return $name;
+    }
+    
     /**
      *
      * @url GET /ipv4
