@@ -123,7 +123,7 @@ class SMTSwitchService extends SMTService implements SMTIService
      * @url GET /
      *
      * @access protected
-     * @class SMTAccessControl {@requires install}
+     * @class SMTAccessControl {@requires user}
      */
     function fetchSwitchConfig()
     {
@@ -434,14 +434,14 @@ class SMTSwitchService extends SMTService implements SMTIService
      * @url GET /rotau/
      *
      * @access protected
-     * @class SMTAccessControl {@requires install}
+     * @class SMTAccessControl {@requires user}
      */
     function fetchRotauConfig()
     {
     	$configDetectRotauDto= new SMTConfDetRotauDto();
     	try
     	{
-	    	if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && SMTOtuType::isOtu8KV2())
+    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
 	    	{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -474,7 +474,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && SMTOtuType::isOtu8KV2())
+    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -507,7 +507,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && SMTOtuType::isOtu8KV2())
+    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
 	    		if ( $this->rotauManager== NULL )
 	    		{
@@ -539,7 +539,7 @@ class SMTSwitchService extends SMTService implements SMTIService
     {
     	try
     	{
-    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && SMTOtuType::isOtu8KV2())
+    		if ( (SMTOtuMode::isONMSi() || SMTOtuMode::isONMS()) && ( SMTOtuType::isOtu8KV2() || SMTOtuType::isCOtu() ) )
     		{
     			$configDetectRotauDto = SMTConfDetRotauDto::getInstance( $request_data );
     			if ( $configDetectRotauDto!= null)
