@@ -955,14 +955,18 @@ class SMTAlarm extends SMTServiceHelper
     /**
      * Clear all alarms on OTU (used to resync alarms)
      */
-    public function clearAllAlarms()
+    public function clearAllAlarms($deleteOtuAlarms = TRUE)
     {
         try 
         {
+        	SMTLogger::getInstance()->trace( "Delete all alarms!",SMTLogger::PINFO);
             $dbConnection = $this->getContext()->getDatabase();
             
             //remove all alarms on OTU
-            $this->send( SMTOtuApi::clearAllAlarmsCommand() );
+            if ( $deleteOtuAlarms )
+            {
+            	$this->send( SMTOtuApi::clearAllAlarmsCommand() );
+            }
             
             //remove all attenuation alarms form SmartOTU database.
             //remove all system alarms from SmartOTU database.
