@@ -36,6 +36,7 @@ use app\serviceshelper\SMTServiceHelper;
 use app\parser\SMTOtuApi;
 use app\services\setup\SMTConfDetModuleDto;
 use app\services\setup\SMTModuleDto;
+use app\admin\SMTOtuMode;
 
 /**
  * 
@@ -46,15 +47,12 @@ class SMTModule extends SMTServiceHelper
 {
     const INDEX_MODULE_POSITION = 0;
     const INDEX_MODULE_TYPE = 1;
-    const MOD1 = "MOD1";
-    const MOD2 = "MOD2";
-    const MOD3 = "MOD3";
-    const MOD_PREFIX = "MOD";
     const MODULE_COUNT = 3;
-    const OTU_DTSS_FUNCTION = "COBRA";
-    const OTU_DTS_FUNCTION  = "DTS";
-    const HIGH_RESOLUTION   = "-2";
-    const HIGH_DYNAMIC      = "-1";
+    const OTU_DTSS_FUNCTION = 'COBRA';
+    const OTU_DTS_FUNCTION  = 'DTS';
+    const HIGH_RESOLUTION   = '-2';
+    const HIGH_DYNAMIC      = '-1';
+    const DWDM_Laser        = '0';
     
     /**
      * Check module number: 0 or 1. Throw exception if the test fails.
@@ -164,11 +162,11 @@ class SMTModule extends SMTServiceHelper
     function isDifference()
     {        
     	//module found in MOD1 or MOD2 or MOD3
-    	$difference = ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, self::MOD1 ) ) != SMTOtuApi::RES_OK );
-    	$difference |= ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, self::MOD2 ) ) != SMTOtuApi::RES_OK );
-    	if (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())
+    	$difference = ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD1 ) ) != SMTOtuApi::RES_OK );
+    	$difference |= ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD2 ) ) != SMTOtuApi::RES_OK );
+    	if ( (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2()) && !SMTOtuMode::isONMS() )
     	{
-    	    $difference |= ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, self::MOD3 ) ) != SMTOtuApi::RES_OK );
+    		$difference |= ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD3 ) ) != SMTOtuApi::RES_OK );
     	}
     	
     	return $difference;    	
@@ -186,27 +184,28 @@ class SMTModule extends SMTServiceHelper
         $this->fetchModulesConfig( $configDetectModuleDto );
         $difference = FALSE;
         $index = 0;
-        //no MOD3 on compactOTU
-        $moduleCount = (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())? self::MODULE_COUNT : self::MODULE_COUNT - 1;
+        $hasModuleDifference = FALSE;
+        //no MOD3 on compactOTU and in ONMS mode
+        $moduleCount = (SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())&&( !SMTOtuMode::isONMS() )? self::MODULE_COUNT : self::MODULE_COUNT - 1;
         
         while ( $index < $moduleCount )
         {
             $module = $configDetectModuleDto->getConfiguredModule($index);
-            
+            $position = SMTModuleDto::MOD_PREFIX.($index + 1);
             //module found in MOD1 or MOD2 or MOD3
-            $difference = ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, self::MOD_PREFIX.($index + 1) ) ) != SMTOtuApi::RES_OK ); //$module->getPosition() ) ) != "OK" );
-             
-            $configDetectModuleDto->setModuleDifference($index, $difference);
+            $difference = ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, $position) ) != SMTOtuApi::RES_OK ); //$module->getPosition() ) ) != "OK" );
+            $hasModuleDifference |= $difference;
+            $configDetectModuleDto->setModuleDifference($position, $difference);
                         
             //retrieve module settings
             if ( $module != NULL )
             {
-            	$this->fetchCalibrationModuleSettings( $module );            
+            	$this->fetchCalibrationModuleSettings( $module );
             }
             $index++;
         }
 
-        if ( $configDetectModuleDto->hasModuleDifference() || ($configDetectModuleDto->getConfiguredModuleCount() == 0) )
+        if ( $hasModuleDifference || ($configDetectModuleDto->getConfiguredModuleCount() == 0) )
         {
             $index=0;
             $this->fetchModulesDetected( $configDetectModuleDto );
@@ -228,7 +227,7 @@ class SMTModule extends SMTServiceHelper
         //if no link exists
         if ( !is_array( $linksId ) || count( $linksId ) <= 0 || $linksId[0] == NULL || $linksId[0] == "" )
         {
-            $monitoringTests = FALSE;            
+            $monitoringTests = FALSE;
         }
         $configDetectModuleDto->setMonitoringTests($monitoringTests);
         
@@ -236,9 +235,10 @@ class SMTModule extends SMTServiceHelper
         $difference = FALSE;
         while ( $index < $moduleCount)
         {
-            $difference = $configDetectModuleDto->isModuleDifference($index);            
-            $difference = ( $difference || (($configDetectModuleDto->getConfiguredModule($index) == NULL) && ($configDetectModuleDto->getDetectedModule($index) != NULL)));
-            $configDetectModuleDto->setModuleDifference($index, $difference);                        
+        	$position = SMTModuleDto::MOD_PREFIX.($index + 1);
+        	$difference = $configDetectModuleDto->isModuleDifference($position);
+        	$difference = ( $difference || (($configDetectModuleDto->getConfiguredModuleByPosition($position) == NULL) && ($configDetectModuleDto->getDetectedModuleByPosition($position) != NULL)));
+        	$configDetectModuleDto->setModuleDifference($position, $difference);
         	$index++;
         }
         
@@ -281,8 +281,19 @@ class SMTModule extends SMTServiceHelper
 //     	        {
         	        $functionDto = new SMTOtdrFunctionDto();
         	        $functionDto->setName( $function );
-        	        $functionDto->setWavelengthArray( self::parseWavelengthsString( $this->sendReceive( SMTOtuApi::getModuleWavelengths( $moduleDto->getPosition(), $function ) ) ) );
-        	            	        
+        	        
+        	        $moduleWavelengthString = $this->sendReceive( SMTOtuApi::getModuleWavelengths( $moduleDto->getPosition(), $function ) );
+        	        if ( strcasecmp( $moduleWavelengthString, self::DWDM_Laser ) == 0 )
+        	        {
+        	        	$moduleFrequencyParametersString = $this->sendReceive( SMTOtuApi::getModuleFrequencyParameters( $moduleDto->getPosition() ) );
+        	        	self::parseFrequencyParameters( $functionDto, $moduleFrequencyParametersString);
+        	        	
+        	        }
+        	        else
+        	        {
+        	        	$functionDto->setWavelengthArray( self::parseWavelengthsString( $moduleWavelengthString) );
+        	        }
+        	        
             	    $pulses = self::parsePulsesString( $this->sendReceive( SMTOtuApi::getModulePulses( $moduleDto->getPosition(), $function )) );
             	    foreach ( $pulses as $pulse )
             	    {
@@ -312,6 +323,18 @@ class SMTModule extends SMTServiceHelper
     	{
     	    //only one module in smartOTU; WARNING: modify the original array
     	    $moduleDto = array_shift( $modules );
+    	    $functions = $moduleDto->getFunctions();
+    	    
+    	    //always fetch dwdm frequencies, because they can have changed
+    	    foreach ( $functions as &$functionDto )
+    	    { 
+    	    	if ( count( $functionDto->getDwdmFrequenciesArray() ) > 0 ) 
+    	    	{
+    	    		$moduleFrequencyParametersString = $this->sendReceive( SMTOtuApi::getModuleFrequencyParameters( $moduleDto->getPosition() ) );
+    	    		$functionDto->setDwdmFrequenciesArray( array() );
+    	    		self::parseFrequencyParameters( $functionDto, $moduleFrequencyParametersString);
+    	    	}
+    	    }
     	}
     	
     	return $moduleDto;
@@ -328,19 +351,22 @@ class SMTModule extends SMTServiceHelper
     private static function parseModuleString( $moduleString, $detected )
     {
     	$module = NULL;
-    	//retrieve module attributes
-    	$array_module = preg_split("/[:,]+/", $moduleString );
-    	//remove spaces in array values
-    	$array_module = array_map ( "trim", $array_module );
-    	
-    	SMTLogger::getInstance()->trace("MODULE_POSITION ".$array_module[self::INDEX_MODULE_POSITION], SMTLogger::DEBUG);
-    	SMTLogger::getInstance()->trace("MODULE_TYPE ".$array_module[self::INDEX_MODULE_TYPE], SMTLogger::DEBUG );
-    	if ( $array_module[self::INDEX_MODULE_TYPE] != "-1")
+    	if ( strlen($moduleString) > 0)
     	{
-    		$module = new SMTModuleDto();
-    		$module->setDetected($detected);
-    		$module->setPosition( $array_module[self::INDEX_MODULE_POSITION] );
-    		$module->setType( $array_module[self::INDEX_MODULE_TYPE] );
+	    	//retrieve module attributes
+	    	$array_module = preg_split("/[:,]+/", $moduleString );
+	    	//remove spaces in array values
+	    	$array_module = array_map ( "trim", $array_module );
+	    	
+	    	SMTLogger::getInstance()->trace("MODULE_POSITION ".$array_module[self::INDEX_MODULE_POSITION], SMTLogger::DEBUG);
+	    	SMTLogger::getInstance()->trace("MODULE_TYPE ".$array_module[self::INDEX_MODULE_TYPE], SMTLogger::DEBUG );
+	    	if ( is_array($array_module) && (strlen($array_module[self::INDEX_MODULE_TYPE]) > 0) && $array_module[self::INDEX_MODULE_TYPE] != "-1")
+	    	{
+	    		$module = new SMTModuleDto();
+	    		$module->setDetected($detected);
+	    		$module->setPosition( $array_module[self::INDEX_MODULE_POSITION] );
+	    		$module->setType( $array_module[self::INDEX_MODULE_TYPE] );
+	    	}
     	}
     	return $module;
     }
@@ -371,6 +397,19 @@ class SMTModule extends SMTServiceHelper
     	return array_map( 'intval', $wavelengths );    	
     }    
     
+    private static function parseFrequencyParameters( SMTOtdrFunctionDto $functionDto, $moduleFrequencyParametersString )
+    {
+    	$frequencies = explode( ",", $moduleFrequencyParametersString);
+    	$frequencies= array_map ( "trim", $frequencies);
+    	$frequencies = array_map( 'intval', $frequencies);
+    	
+    	list($minFreqGhz, $maxFreqGhz, $spacingGhz) = $frequencies;
+    	for ( $channel= $minFreqGhz; $channel<= $maxFreqGhz; $channel+=$spacingGhz )
+    	{
+    		$functionDto->addDwdmFrequenciesArray ( $channel );
+    	}
+    }
+    
     /**
      * Parse the OTDR module wavelengths string.
      *
