@@ -44,8 +44,15 @@ class SMTMacroSwitchConf extends SMTMacroSwitch
         list( $device, $code, $test ) = explode(',', $result);        
         $this->setSwitchDecoder( parent::GLOB, $code );
         
+        // distributor OSX musn't be fetched twice
+        $nbOsx = $this->getSwitchDecoder( parent::GLOB)->getOSUCount();
+        if ( $nbOsx >= self::OSU_DISTRIBUTOR_INDEX)
+        {
+        	$nbOsx = self::OSU_DISTRIBUTOR_INDEX -1 ;
+        }
+        
         //retrieve OSU if needed: WARNING only retrieve OSU1 and OSU2 in simplified mode
-        for ( $osuCount = 1; $osuCount <= $this->getSwitchDecoder( parent::GLOB)->getOSUCount(); $osuCount++)
+        for ( $osuCount = 1; $osuCount <= $nbOsx; $osuCount++)
         {
             $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_config_desc, SMTSwitchManager::MACRO_SWITCH_ID, parent::OSU.$osuCount ) );
             list( $device, $code, $test ) = explode(',', $result);
