@@ -36,7 +36,7 @@ class SMTSwitchDecoder
     /**
      * OSU count per topologies excluding topologies M,N,P,Q,X,Y where the number of OSU is given directly in the configuration string
      */
-    private $osu_Topologies = array("A"=>0,"B"=>1,"C"=>2,"D"=>1,"E"=>0,"F"=>0,"G"=>0,"H"=>0,"I"=>1,"J"=>1,"K"=>0,"L"=>4,"R"=>1, "T"=>2);  
+    private $osu_Topologies = array("A"=>0,"B"=>1,"C"=>2,"D"=>1,"E"=>0,"F"=>0,"G"=>0,"H"=>0,"I"=>1,"J"=>1,"K"=>0,"L"=>4,"R"=>1, "T"=>2,"U"=>1);  
     
     /**
      * Construtor to set the given switch configuration string
