@@ -19,7 +19,7 @@ $noUploadRunning = SMTUploadStatus::checkNoUploadRunning();
 
 if ( $noUploadRunning )
 {
-    $uploadStatus = upload_file( SMTOtuBackupRestore::OTU_BACKUP_DIR, TRUE );    
+    $uploadStatus = upload_file( SMTOtuBackupRestore::OTU_BACKUP_DIR, 'checkBackup' );    
     
     if ( $uploadStatus->getUploadErrorStatus() == SMTUploadStatusDto::NO_ERROR )
     {
@@ -33,6 +33,9 @@ else
     $uploadStatus->setProgress( SMTUploadStatusDto::NO_UPLOAD );
     $uploadStatus->setUploadErrorStatus( SMTUploadStatusDto::UPLOAD_ALREADY_RUNNING );
     SMTLogger::getInstance()->trace("Upload already running...", SMTLogger::ERROR);
+    
+    // add error code 401 in case of upload failure
+    @header('Cache-Control: no-cache, must-revalidate', true, 401 ); 
 }
 
 $response = buildJsonResponse( $uploadStatus );
