@@ -82,13 +82,24 @@ class SMTUploadStatus
     {
     	$noUploadRunning = TRUE;
     
-    	//retrieve php upload progress from apc
-    	$apcStatus = apc_fetch( self::UPLOAD_PROGRESS_IN_APC.self::OTU_UPLOAD_PROGRESS_KEY );
+    	if ( PHP_MAJOR_VERSION >= 6 )
+    	{
+    		$key = ini_get("session.upload_progress.prefix").self::OTU_UPLOAD_PROGRESS_KEY;//$_POST[ini_get("session.upload_progress.name")];
+    		
+    		SMTLogger::getInstance()->trace("Get upload info with key ".$key, SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+    		
+    		$apcStatus = (isset($_SESSION[$sessionKey])) ? $_SESSION[$sessionKey] : FALSE;
+    	}
+    	else
+    	{
+	    	//retrieve php upload progress from apc
+    		$apcStatus = apc_fetch( self::UPLOAD_PROGRESS_IN_APC.self::OTU_UPLOAD_PROGRESS_KEY );
+    	}
     
     	//an upload is running
-    	if ( $apcStatus != FALSE && ( array_key_exists('done', $apcStatus) && ($apcStatus['done'] != "1" ) && ( array_key_exists('cancel_upload', $apcStatus) && $apcStatus['cancel_upload'] != "1" ) ) )
+    	if ( $apcStatus != FALSE && ( array_key_exists('done', $apcStatus) && (($apcStatus['done'] != "1") && ($apcStatus['done'] != "true") ) && ( array_key_exists('cancel_upload', $apcStatus) && ($apcStatus['cancel_upload'] != "1") ) ) )
     	{
-    		SMTLogger::getInstance()->trace('apcStatus[done]'.$apcStatus['done'].'apcStatus[cancel_upload]'.$apcStatus['cancel_upload'] );
+    		SMTLogger::getInstance()->trace('apcStatus[done]='.$apcStatus['done'].' apcStatus[cancel_upload]='.$apcStatus['cancel_upload'] );
     		$noUploadRunning = FALSE;
     	}
     	else if ( self::isUploadRelaseRunning() )
@@ -114,28 +125,67 @@ class SMTUploadStatus
     	$uploadProgress = SMTUploadStatusDto::NO_UPLOAD;
     	$uploadRate = SMTUploadStatusDto::NO_RATE;
     	$errorStatus = SMTUploadStatusDto::NO_ERROR;
-    	$cacheDto = SMTUploadStatus::getCurrentUploadInfoFromCache();
+    	$cacheDto = self::getCurrentUploadInfoFromCache();
     
-    	//retrieve php upload progress from apc
-    	$apcStatus = apc_fetch( self::UPLOAD_PROGRESS_IN_APC.$id );
-    
-    	//an upload is running
-    	if ( $apcStatus != FALSE )
+    	if ( PHP_MAJOR_VERSION >= 6 )
     	{
-    		$uploadProgress = round( $apcStatus['current']/$apcStatus['total']*100.0 );
-    		$bytesUploaded = intval( $apcStatus['current'] );
-    		$uploadRate = 0;
-    		if ( floatval( $apcStatus['start_time'] ) > 0 )
+    		$key = ini_get("session.upload_progress.prefix") . $id;//$_POST[ini_get("session.upload_progress.name")];
+    		
+//     		SMTLogger::getInstance()->trace(ini_get("session.upload_progress.prefix")."  ".ini_get("session.upload_progress.name"), SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+//     		SMTLogger::getInstance()->trace("Get upload info with key ".$key, SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+//     		SMTLogger::getInstance()->trace("Session info: ".print_r($_SESSION, TRUE), SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+    		
+    		$uploadInfo = (isset($_SESSION[$key])) ? $_SESSION[$key] : NULL;
+    		if ( $uploadInfo != NULL )
     		{
-    			$elapseTime = microtime(true) - floatval( $apcStatus['start_time'] );
-    			$uploadRate = $bytesUploaded / $elapseTime;
-    			$uploadRate = round( $uploadRate/1000000.0, 2);
+//      			SMTLogger::getInstance()->trace("Upload info: ".print_r($_SESSION[$key], TRUE), SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+    			$uploadProgress = round( ($uploadInfo['bytes_processed']/$uploadInfo['content_length'])*100.0 );
+    			$bytesUploaded = intval( $uploadInfo['bytes_processed']);
+    			$uploadRate = 0;
+    			if ( floatval( $uploadInfo['start_time'] ) > 0 )
+    			{
+    				$elapseTime = microtime(true) - floatval( $uploadInfo['start_time'] );
+    				$uploadRate = $bytesUploaded / $elapseTime;
+    				$uploadRate = round( $uploadRate/1000000.0, 2);
+    			}
+    		}
+    		//no upload is running, retrieve error status from cache ( it can only be computed by upload process (SMTUpload.php) at the end of the upload)
+    		else if( $cacheDto != NULL )
+    		{
+    			$errorStatus = $cacheDto->getUploadErrorStatus();
+    		}
+    		else if ( self::isUploadRelaseRunning() )
+    		{
+    			SMTLogger::getInstance()->trace("Upload release still running: checking release");
+    		}
+    		else
+    		{
+    			SMTLogger::getInstance()->trace("Couldn't get upload info with key ".$key, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
     		}
     	}
-    	//no upload is running, retrieve error status from cache ( it can only be computed by upload process (SMTUpload.php) at the end of the upload)
-    	else if( $cacheDto != NULL )
+    	else
     	{
-    		$errorStatus = $cacheDto->getUploadErrorStatus();
+	    	//retrieve php upload progress from apc
+	    	$apcStatus = apc_fetch( self::UPLOAD_PROGRESS_IN_APC.$id );
+	    
+	    	//an upload is running
+	    	if ( $apcStatus != FALSE )
+	    	{
+	    		$uploadProgress = round( $apcStatus['current']/$apcStatus['total']*100.0 );
+	    		$bytesUploaded = intval( $apcStatus['current'] );
+	    		$uploadRate = 0;
+	    		if ( floatval( $apcStatus['start_time'] ) > 0 )
+	    		{
+	    			$elapseTime = microtime(true) - floatval( $apcStatus['start_time'] );
+	    			$uploadRate = $bytesUploaded / $elapseTime;
+	    			$uploadRate = round( $uploadRate/1000000.0, 2);
+	    		}
+	    	}
+	    	//no upload is running, retrieve error status from cache ( it can only be computed by upload process (SMTUpload.php) at the end of the upload)
+	    	else if( $cacheDto != NULL )
+	    	{
+	    		$errorStatus = $cacheDto->getUploadErrorStatus();
+	    	}
     	}
     
     	$dto = new SMTUploadStatusDto();
@@ -179,24 +229,39 @@ class SMTUploadStatus
      */
     public static function cleanPhpUploadProgressFromApcCache()
     {
-    	$key = self::UPLOAD_PROGRESS_IN_APC.self::OTU_UPLOAD_PROGRESS_KEY;
-    	$success = FALSE;
-    	$deleteTrialCount = 0;
-    	$maxDeleteTrialCount = 50;
-    	if ( apc_exists( $key ) )
+    	if ( PHP_MAJOR_VERSION >= 6 )
     	{
-    		while ( !$success && $deleteTrialCount < $maxDeleteTrialCount )
+    		$key = ini_get("session.upload_progress.prefix").self::OTU_UPLOAD_PROGRESS_KEY;//$_POST[ini_get("session.upload_progress.name")];
+    		
+    		SMTLogger::getInstance()->trace("Get upload info with key ".$key, SMTLogger::INFO, __FILE__,__METHOD__,__LINE__);
+    		
+    		$uploadInfo = (isset($_SESSION[$sessionKey])) ? $_SESSION[$sessionKey] : NULL;
+    		if ( $uploadInfo != NULL )
     		{
-    			$deleteTrialCount++;
-    			usleep(rand(1000, 10000));
-    			$success = apc_delete( $key );
-    		}
-    		if ( !$success )
-    		{
-    			SMTLogger::getInstance()->trace("Couldn't delete ".$key." from APC store.".$key, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
+    			unset($_SESSION[$sessionKey]);
     		}
     	}
-    }    
+    	else
+    	{
+	    	$key = self::UPLOAD_PROGRESS_IN_APC.self::OTU_UPLOAD_PROGRESS_KEY;
+	    	$success = FALSE;
+	    	$deleteTrialCount = 0;
+	    	$maxDeleteTrialCount = 50;
+	    	if ( apc_exists( $key ) )
+	    	{
+	    		while ( !$success && $deleteTrialCount < $maxDeleteTrialCount )
+	    		{
+	    			$deleteTrialCount++;
+	    			usleep(rand(1000, 10000));
+	    			$success = apc_delete( $key );
+	    		}
+	    		if ( !$success )
+	    		{
+	    			SMTLogger::getInstance()->trace("Couldn't delete ".$key." from APC store.".$key, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
+	    		}
+	    	}
+    	}
+    }
 }
 
 
